nvector.objects.GeoPoint
========================

.. currentmodule:: nvector.objects

.. autoclass:: GeoPoint

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GeoPoint.__init__
      ~GeoPoint.delta_to
      ~GeoPoint.displace
      ~GeoPoint.distance_and_azimuth
      ~GeoPoint.to_ecef_vector
      ~GeoPoint.to_geo_point
      ~GeoPoint.to_nvector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GeoPoint.latitude_deg
      ~GeoPoint.latlon
      ~GeoPoint.latlon_deg
      ~GeoPoint.longitude_deg
   
   